classdef IceLoadLimitForce
    %IceLoadLimitForce: Calculates limiting driving force on large
    %   floes, based on theory in section 5.7 of thesis.
    
    
    %% PROPERTIES
    properties
       HorizontalForce
       VerticalForce
       Platform
       EnvParameters
       IceParameters 
    end %properties
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadLimitForce(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;
        end %function
        
        function obj = CalcIceLoadLimitForce(obj)
            
            obj.HorizontalForce = (obj.IceParameters.C_w*...
                obj.EnvParameters.rho_a*(obj.EnvParameters.V_w)^2*...
                (obj.IceParameters.L)^2) + obj.IceParameters.w*...
                obj.IceParameters.L;
            
            obj.VerticalForce = obj.HorizontalForce/((obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha)));
        end %function
        
    end %methods
      
    
end