classdef IceLoadRidgeDolgopolov
    % Class for calculating ridge forces by first-year ridge, based on
    % method by Dolgopolov in section 5.3.1 of thesis.

    %% PROPERTIES
    properties
        HorizontalForce
        VerticalForce
        Platform
        EnvParameters
        IceParameters
    end
    
    properties
        eta
        q
        gamma
    end
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadRidgeDolgopolov(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;
        end
    end
    
    methods
        function obj = CalculateEta(obj)
            obj.eta = sqrt((1+sind(obj.IceParameters.omega))/(1-sind(obj.IceParameters.omega)));
        end
        
        function obj = Calculateq(obj)
            obj.q = 1 + ((2*obj.IceParameters.B_s)/(3*obj.Platform.D));
        end
        
        function obj = Calculategamma(obj)
            obj.gamma = (obj.EnvParameters.rho_w - obj.IceParameters.rho_i)*...
                obj.EnvParameters.g*(1-obj.IceParameters.n);
        end
        
        function obj = CalculateHorizontalForce(obj)
            obj = obj.CalculateEta();
            obj = obj.Calculateq();
            obj = obj.Calculategamma();
            
            obj.HorizontalForce = obj.IceParameters.h_k*obj.Platform.D*...
                obj.q*(((obj.IceParameters.h_k*obj.gamma*obj.eta^2)/(2))+2*obj.eta*obj.IceParameters.c);
        end 
        
        function obj = CalculateVerticalForce(obj)
            obj = obj.CalculateHorizontalForce();

            
            obj.VerticalForce = obj.HorizontalForce/((obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha)));
        end
        
    end

    
end

