classdef IceLoadRidgeMellor
    % Class for calculating ridge forces by first-year ridge, based on
    % method by Dolgopolov in section 5.3.2 of the thesis.
    
    %% PROPERTIES
    properties
        HorizontalForce
        HorizontalForceSail
        HorizontalForceKeel
        VerticalForce
        Platform
        EnvParameters
        IceParameters
    end
    
    properties(GetAccess ='private', SetAccess = 'private')
        eta
    end
    
    %% METHODS
    methods
        %Class constructor
        function obj = IceLoadRidgeMellor(Platform,EnvParameters,IceParameters)
            obj.Platform = Platform;
            obj.EnvParameters = EnvParameters;
            obj.IceParameters = IceParameters;
        end
    end
    
    methods
        function obj = CalculateEta(obj)
            obj.eta = sqrt((1+sind(obj.IceParameters.omega))/(1-sind(obj.IceParameters.omega)));
        end
        
        function obj = CalculateForces(obj)
            obj = obj.CalculateEta();
            
            obj.HorizontalForceSail = (0.5*obj.Platform.D*obj.eta^2*(1-obj.IceParameters.n)...
                *obj.IceParameters.rho_i*obj.EnvParameters.g*obj.IceParameters.h_s^2)+(2*obj.Platform.D...
                *obj.IceParameters.c*obj.eta*obj.IceParameters.h_s);
            
            obj.HorizontalForceKeel = (0.5*obj.Platform.D*obj.eta^2*(1-obj.IceParameters.n)*...
                (obj.EnvParameters.rho_w - obj.IceParameters.rho_i)*obj.EnvParameters.g*...
                obj.IceParameters.h_k^2)+(2*obj.Platform.D*...
                obj.IceParameters.c*obj.eta*obj.IceParameters.h_k);
            
            obj.HorizontalForce = obj.HorizontalForceSail + obj.HorizontalForceKeel;
        end
        
        function obj = CalculateVerticalForce(obj)
            obj = obj.CalculateForces();

            obj.VerticalForce = obj.HorizontalForce/((obj.IceParameters.mu*cos(obj.Platform.alpha)-sin(obj.Platform.alpha))/...
                        (obj.IceParameters.mu*sin(obj.Platform.alpha)+cos(obj.Platform.alpha)));
        end
    end
    
end

