classdef IceParameters
    %IceParameters: Contains parameters for ice. Values are also given
    %   in table 5.1 in the thesis.
   
   properties % Level ice
       mu           % Friction coefficient
       rho_i        % Density of ice
       sigma_f      % Flexural strength of ice
       E            % Elastic modulus of ice
       nu           % Poisson ratio of ice
       h            % Level ice thickness
       h_k          % Keel depth, first-year ridge
       h_s          % Sail height, first-year ridge
       B_s          % Sail width, first-year ridge
       omega        % Angle of internal friction, first-year ridge
       n            % Void ratio
       h_r          % Thickness of multi-year ridge
       B_t          % Top width of ridge
       B_b          % Bottom width of ridge
       sigma_r      % Strength of ridge ice
       h_f          % Thickness of managed floes
       e            % Porosity of ice
       phi          % Ice rubble friction coefficient
       c            % Ice rubble cohesion
       K            % Bearing capacity
       K_0          % Vertical/lateral rubble pressure ration
       p            % Ice pressure
       theta        % Angle of staitonary ice rubble block
       L            % Length and width of ice floe
       w            % Ridge building force
       C_w          % Wind drag coefficient
       V            % Ice drift speed
   end
    
   methods
       %class constructor
       function obj=IceParameters(Input)
          obj.mu      = Input.mu;
          obj.rho_i   = Input.rho_i;
          obj.sigma_f = Input.sigma_f;
          obj.E       = Input.E;
          obj.nu      = Input.nu;
          obj.h       = Input.h;
          obj.h_k     = Input.h_k;
          obj.h_s     = Input.h_s;
          obj.B_s     = Input.B_s;
          obj.omega   = Input.omega;
          obj.n       = Input.n;
          obj.h_r     = Input.h_r;
          obj.B_t     = Input.B_t;      
          obj.B_b     = Input.B_b;  
          obj.sigma_r = Input.sigma_r;
          obj.h_f     = Input.h_f;
          obj.e       = Input.e;
          obj.p       = Input.p;
          obj.c       = Input.c;
          obj.K       = Input.K;
          obj.K_0     = Input.K_0;
          obj.phi     = Input.phi;          
          obj.theta   = Input.theta*(pi/180);
          obj.C_w     = Input.C_w;
          obj.L       = Input.L;
          obj.w       = Input.w;
          obj.V       = Input.V;
       end
   end
    
    
    
end