function  DynamicInteraction()

clear all
close all
clc



alpha = 25*((pi)/(180));
L_pp = 109;
width = 25;
T = 10;
g = 9.81;
mu = 0.1;
mass = 25*10^6;
Amass = 0.02*mass;
k = 400000; %stiffness of mooring system[N/m]
rho_w = 1025;
rho_i = 917;
h_i = 1;
v_i = 0.1;
E = 5*10^9;
I = (width*h_i^3)/12;
lambda = ((rho_w*g*width)/(4*E*I))^0.25;

e1 = ((sin(alpha)+mu*cos(alpha))/(cos(alpha)-mu*sin(alpha)));
sigma_f_crit = 5*10^5;
dampingratio = 0.15;

omega_0 = sqrt((k)/(mass+Amass));
    
    
    X_0 = 0;
    
    %Distance penetrated by the vessel in the ice sheet
    k = ((v_i*1) - X_0);
    
    %Edge deflection of ice beam
    u = k*tan(alpha);
    
    %Calculate force N
    
    %Perform iteration to determine N
    for i = 1:100
        if i == 1
            N_0 = 1000; %Initial guess
        else
            N_0 = N;
        end
         
        N = ((2*E*I*e1*u*lambda^4)/(sqrt(lambda^2-((N_0)/(4*E*I)))));
        
    end
       
       
        
    
    a = sqrt((lambda^2) + ((N)/(4*E*I)));
    b = sqrt((lambda^2) - ((N)/(4*E*I)));
    
    P = N*e1;
  
    
    %Find moment at free end of ice beam
    ddu = -((2*P)/(E*I))*((a^3*b)/(2*a^3*b^2+a*b^4+a^5))...
          +((2*P)/(E*I))*((a*b^3)/(2*a^3*b^2+a*b^4+a^5))...
          -((P)/(E*I))*(((a*b^3)-(a^3*b))/(2*a^3*b^2+a*b^4+a^5));
      
    M = -E*I*ddu;
    
    %Calculate stress due to moment
    sigma_f = M*(6/width);
    
    %Check if stress in ice beam is equal or more than failure stress
    if sigma_f >= sigma_f_crit
        disp('Ice beam fails')
        return 
    end
    
    F_break_ice = N;
    
    %Calculate friction force
    F_friction = mu*(rho_w-rho_i)*g*(L_pp-((T)/(tan(alpha))))*width*h_i;
    
    F_ice = F_break_ice + F_friction;
    
    %Solve equation of motion using Matlab's ode45 function
    %Define a system of first order ODE' that Matlab can solve
    
    T=0:0.1:400;
    %T=[0 0.1]; %Time span for solution
    initial_x = 0;
    initial_dxdt = 0;
    x0 = [initial_x initial_dxdt];
    
    [T,x] = ode45(@rhs,T,x0);

    function dxdt = rhs(~,x)
        dxdt_1 = x(2);
        dxdt_2 = -(2*dampingratio*omega_0*x(2))-(omega_0^2*x(1))+(((1)/(mass+Amass))*F_ice);
        
        dxdt = [dxdt_1; dxdt_2];
    end

    
    figure(1)
    plot(T,x);
    

    
    
 
    
    %Find displacement after time t
    DispDueToForce = max(x(:,1));

    
   
    end    



