function SolveEqMotion()

clear all
close all
clc

%Constants
g = 9.81;
mu = 0.1;

%Ship particulars
alpha = 25*((pi)/(180));
L_pp = 109;
width = 25;
T = 10;
mass = 25*10^6;
Amass = 0.02*mass;
K = 100000; %stiffness of mooring system[N/m]
dampingratio = 0.05;
omega_0 = sqrt((K)/(mass+Amass));

%Ice constants
rho_w = 1025;
rho_i = 917;
h_i = 1;
v_i = 0.05;
E = 5*10^9;
I = (width*h_i^3)/12;
lambda = ((rho_w*g*width)/(4*E*I))^0.25;
e1 = ((sin(alpha)+mu*cos(alpha))/(cos(alpha)-mu*sin(alpha)));
sigma_f_crit = 5*10^5;

deltaJ = 0.1;
timestop = 2000;
t = 1; %internal counter
X = zeros(1,(timestop/deltaJ)+1); %Displacement
Xdot = zeros(1,(timestop/deltaJ)+2); %Velocity 
Disp = zeros(1,(timestop/deltaJ)+2);
Vel = zeros(1,(timestop/deltaJ)+2);
F_ice = zeros(1,(timestop/deltaJ)+2);
F_break_ice = zeros(1,(timestop/deltaJ)+2);
F_rotation = zeros(1,(timestop/deltaJ)+2);
P = zeros(1,(timestop/deltaJ)+1);
k = zeros(1,(timestop/deltaJ)+2);
lb = randnumber();
Lb = lb;

F_friction = mu*(rho_w-rho_i)*g*(L_pp-((T)/(tan(alpha))))*width*h_i;
F_ice(1) = F_friction;

J = 0;
r = 1;
S = 0;
relDisp = 0;

%% Convert equation of motion into system of first order ODE's
function dxdt = rhs(Time,x)
        dxdt_1 = x(2);
        dxdt_2 = -(2*dampingratio*omega_0*x(2))-(omega_0^2*x(1))+(((1)/(mass+Amass))*F_ice(t));
        
        dxdt = [dxdt_1; dxdt_2];
end

%% Function to calculate breaking force of ice
function N = CalculateBreakingForce()
        

      for i = 1:10
        if i == 1
         N_0 = 10; %Initial guess
        else
         N_0 = N;
        end
         N = ((2*E*I*e1*u_int*lambda^4)/(sqrt(lambda^2-((N_0)/(4*E*I)))));
      end
        
      P(t) = N/e1; %Vertical force
      
end



%% MAIN TIME SIMULATION
    for j = 0:deltaJ:timestop
      
        t = t + 1;
        
        if j == 0
            X(t) = 0;
        else
            X(t) = Disp(t-1);
            Xdot(t) = Vel(t-1);
        end
        
        %Distance penetrated by the vessel in the ice sheet
        k(t) = ((v_i*j) - X(t));
        
        %Determine maximum vertical force that breakes ice beam
        Pmax = ((3*rho_w*g*h_i^5)/(E))^0.25 *((exp(pi*0.25))...
            /(6*sin(pi*0.25)))*sigma_f_crit*width;     
        
        
        
        if P(t-1) < Pmax && J == 0
            %disp('Ice beam deflects')
            k_int1 = (S+(relDisp+(X(t)-X(t-1)))) - X(t);
            u_int = k_int1*tan(alpha);
            %Deflection of ice sheet starts, and continues until it breaks.
            F_rotation(t) = 0;
            N = CalculateBreakingForce();
            F_break_ice(t) = N;
            S = S + deltaJ;
            R = 0;
            
        else
            a_j = k_int1;
            J = 1; %Prevent entering breaking phase
            F_break_ice(t) = 0;
            %disp('Ice beam rotates')
            %Rotation force
            Ep_j = 0.5*(rho_w-rho_i)*g*lb^2*width*h_i*sin(alpha);
            V_rotj = ((Ep_j)/(lb-a_j));
            F_rotation(t) = V_rotj*e1;
            %Internal counter to measure length of penetration
                      
            %When floe is completely rotated a new breaking phase starts
            
            if k(t) >= Lb
                J = 0;
                relDisp = X(t);
                r = r + 1;
                lb = randnumber();
                Lb = Lb + lb;
            end
            
            R = R + deltaJ;
            S = 0;
        end
            
        F_ice(t) = F_friction + F_break_ice(t) + F_rotation(t);

        
        %Solve equation of motion using Matlab's ode45 function
        %Define a system of first order ODE' that Matlab can solve
    
        Time=[j (j+deltaJ)]; %Time span for solution
        initial_x = X(t); %Initial displacement
        initial_dxdt = Xdot(t); %Initial velocity
        xinitial = [initial_x initial_dxdt];
    
        [Time,x] = ode45(@rhs,Time,xinitial);
        
        Disp(t) = x(end,1);
        
        Vel(t) = x(end,2);
        
            
         
    end

    R = 0:deltaJ:timestop+deltaJ;
    
        %plot displacement and velocity vs time    
        subplot(2,2,1)
        plot(R,Disp,R,Vel)
        xlabel('Time [s]')
        legend('Displacement of platform','Velocity of platform')
        grid on
       
        subplot(2,2,2)
        plot(R,k)
        xlabel('Time [s]')
        ylabel('Penetration in ice sheet [m]')
        grid on

        subplot(2,2,3)
        plot(R,F_ice,R,Disp.*K)
        xlabel('Time [s]')
        ylabel('Ice Force [N]')
        legend('Ice Force','Mooring Force')
        xlim([1000 1400])
        ylim([0 500001])
        grid on
        
        subplot(2,2,4)
        plot(k,F_ice)
        xlabel('Penetration in ice sheet [m]')
        ylabel('Ice Force [N]')
        xlim([0 10])
        grid on
        
end