%% Function to calculate breaking force of ice
function F_break_ice = CalculateBreakingForce()
        
        %Edge deflection of ice beam
        u = k*tan(alpha);
       

        %Perform iteration to determine force N
        for i = 1:10
            if i == 1
                N_0 = 10; %Initial guess
            else
                N_0 = N;
            end
         
            N = ((2*E*I*e1*u*lambda^4)/(sqrt(lambda^2-((N_0)/(4*E*I)))));
        
        end
        
        a = sqrt((lambda^2) + ((N)/(4*E*I)));
        b = sqrt((lambda^2) - ((N)/(4*E*I)));
        
        P = N/e1; %Vertical force
        
        A = ((2*P)/(E*I))*((a*b)/(2*a^3*b^2 + a*b^4 + a^5));
        B = ((P)/(E*I))*((b^2-a^2)/(2*a^3*b^2 + a*b^4 + a^5));
    
        %Find moment at free end of ice beam
        ddu = (b^2*exp(-b*Lb)*A*cos(alpha*Lb))+(b*exp(-b*Lb)*A*sin(alpha*Lb)*alpha)...
            +(b*exp(-b*Lb)*A*sin(alpha*Lb)*alpha)-(exp(-b*Lb)*A*cos(alpha*Lb)*alpha^2)...
            +(b^2*exp(-b*Lb)*B*sin(alpha*Lb))-(b*exp(-b*Lb)*B*cos(alpha*Lb)*alpha)...
            -(b*exp(-b*Lb)*B*cos(alpha*Lb)*alpha)-(exp(-b*Lb)*B*sin(alpha*Lb)*alpha^2);
        ddudt(t) = ddu;
      
        M(t) = abs(E*I*ddu);
    
        %Calculate stress due to moment
        sigma_f(t) = ((6*M(t))/(width*h_i^2));
    
        %Check if stress in ice beam is equal or more than failure stress
        if sigma_f(t) >= sigma_f_crit
            disp('Ice beam fails')
            F_break_ice = 0;
            J = J + 1;
           
        else
            F_break_ice = N;
        end
        
end

%% Function to calculate breaking force of ice
function F_break_ice = CalculateBreakingForce()
        
        %Determine maximum vertical force that breakes ice beam
        Pmax = ((3*rho_w*g*h_i^5)/(E))^0.25 *((exp(pi*0.25))...
            /(6*sin(pi*0.25)))*sigma_f_crit*width;     
        P = 0;
        t_int = -deltaJ;
        t_counter = 0;
        
        while P <= Pmax
            t_counter = t_counter + 1;
            t_int = t_int + deltaJ;
            k_int(t_counter) = ((v_i*t_int) - X(t));
            u_int = k_int(t_counter) * tan(alpha);
            
            for i = 1:10
                if i == 1
                    N_0 = 10; %Initial guess
                else
                    N_0 = N;
                end
         
                N = ((2*E*I*e1*u_int*lambda^4)/(sqrt(lambda^2-((N_0)/(4*E*I)))));
        
            end
        
        P = N/e1; %Vertical force
        
        F_break_ice(t) = N;
        J = 0;   
        
        end
 
        J = 1;
        a_j = k_int(t_counter);
      
end
