clear all
close all
clc

%Constants
g = 9.81;
mu = 0.1;

%Ship particulars
alpha = 25*((pi)/(180));
L_pp = 109;
width = 25;
T = 10;
mass = 25*10^6;
Amass = 0.02*mass;
K = 400000; %stiffness of mooring system[N/m]
dampingratio = 0.15;
omega_0 = sqrt((K)/(mass+Amass));

%Ice constants
rho_w = 1025;
rho_i = 917;
h_i = 1;
v_i = 0.1;
E = 5*10^9;
I = (width*h_i^3)/12;
lambda = ((rho_w*g*width)/(4*E*I))^0.25;
e1 = ((sin(alpha)+mu*cos(alpha))/(cos(alpha)-mu*sin(alpha)));
sigma_f_crit = 4.5*10^5;

deltaJ = 0.01;
timestop = 20;
t = 0; %internal counter
X = zeros(1,(timestop/deltaJ)+1); %Displacement
Xdot = zeros(1,(timestop/deltaJ)+1); %Velocity 
Disp = zeros(1,(timestop/deltaJ)+1);
Vel = zeros(1,(timestop/deltaJ)+1);
F_ice = zeros(1,(timestop/deltaJ)+1);
sigma_f = zeros(1,(timestop/deltaJ)+1);
M = zeros(1,(timestop/deltaJ)+1);

F_friction = mu*(rho_w-rho_i)*g*(L_pp-((T)/(tan(alpha))))*width*h_i;

J = 0;
Lb = 20;
j = 0.02;

  k = ((v_i*j));
  u = k*tan(alpha);
       

        %Perform iteration to determine force N
        for i = 1:10
            if i == 1
                N_0 = 10; %Initial guess
            else
                N_0 = N;
            end
         
            N = ((2*E*I*e1*u*lambda^4)/(sqrt(lambda^2-((N_0)/(4*E*I)))));
        
        end
        
        a = sqrt((lambda^2) + ((N)/(4*E*I)));
        b = sqrt((lambda^2) - ((N)/(4*E*I)));
        
        P = N/e1; %Vertical force
        
        A = ((2*P)/(E*I))*((a*b)/(2*a^3*b^2 + a*b^4 + a^5));
        B = ((P)/(E*I))*((b^2-a^2)/(2*a^3*b^2 + a*b^4 + a^5));
    
        %Find moment at free end of ice beam
        ddu = (b^2*exp(-b*Lb)*A*cos(alpha*Lb))+(b*exp(-b*Lb)*A*sin(alpha*Lb)*alpha)...
            +(b*exp(-b*Lb)*A*sin(alpha*Lb)*alpha)-(exp(-b*Lb)*A*cos(alpha*Lb)*alpha^2)...
            +(b^2*exp(-b*Lb)*B*sin(alpha*Lb))-(b*exp(-b*Lb)*B*cos(alpha*Lb)*alpha)...
            -(b*exp(-b*Lb)*B*cos(alpha*Lb)*alpha)-(exp(-b*Lb)*B*sin(alpha*Lb)*alpha^2);
       
      
        M = abs(E*I*ddu);
    
        %Calculate stress due to moment
        sigma_f = ((6*M)/(width*h_i^2));