%Main.m file contains all definitions of objects, and calls to methods of
%objects which perform the necessary calculations. Input parameters can 
%be modified in the Input.m file.

clear all
clc

%% Define objects of the classes.

%Define object of class input, wich contains all input parameters from user
Input = Input();
%Input = Input(h,h_ridge,B_t,B_b,h_f);

%Define object of class Platform
Platform = Platform(Input);

%Define object of Class EnvParameters
EnvParameters = EnvParameters(Input);

%Construct object of class IceParameters
IceParameters = IceParameters(Input);

%Construct object of class Mooring
MooringParameters = MooringParameters(Input);

%Define object of class IceLoadRalston
IceLoadRalston = IceLoadRalston(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadCroasdale
IceLoadCroasdale = IceLoadCroasdale(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadRidgeDolgopolov
IceLoadRidgeDolgopolov = IceLoadRidgeDolgopolov(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadRidgeDolgopolov
IceLoadRidgeMellor = IceLoadRidgeMellor(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadRidgeWang
IceLoadRidgeWang = IceLoadRidgeWang(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadRidgeRalston
IceLoadRidgeRalston = IceLoadRidgeRalston(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadManagedIce
IceLoadManagedIce = IceLoadManagedIce(Platform,EnvParameters,IceParameters);

%Define object of class IceLoadLimitForce
IceLoadLimitForce = IceLoadLimitForce(Platform,EnvParameters,IceParameters);

%Define object of class Mooring
RestoringCoefficients = RestoringCoefficients(MooringParameters,EnvParameters);


%% Perform calculations

%Calculate horizontal and vertical forces from Ralston's equation
IceLoadRalston = IceLoadRalston.horizontalForce();
IceLoadRalston = IceLoadRalston.verticalForce();

%Calculate horizontal force from Croasdale's equation
IceLoadCroasdale = IceLoadCroasdale.horizontalForce();
IceLoadCroasdale = IceLoadCroasdale.verticalForce();

%Calculate forces from first-year ridge, method by Dolgopolov
IceLoadRidgeDolgopolov = IceLoadRidgeDolgopolov.CalculateHorizontalForce();
IceLoadRidgeDolgopolov = IceLoadRidgeDolgopolov.CalculateVerticalForce();

%Calculate forces from first-year ridge, method by Mellor
IceLoadRidgeMellor = IceLoadRidgeMellor.CalculateForces();
IceLoadRidgeMellor = IceLoadRidgeMellor.CalculateVerticalForce();

%Calculate forces from multi-year ridge, based on method by Wang
IceLoadRidgeWang = IceLoadRidgeWang.CalculateForces();

%Calculate forces from multi-year ridge, based on Ralston's method
IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateVerticalInitForce();
IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateVerticalForceCrack();
IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateHorizontalInitForce();
IceLoadRidgeRalston = IceLoadRidgeRalston.CalculateHorizontalForceCrack();

%Calculate forces due to managed ice
IceLoadManagedIce = IceLoadManagedIce.Scenario1();
IceLoadManagedIce = IceLoadManagedIce.Scenario2();
IceLoadManagedIce = IceLoadManagedIce.Scenario3();

%Calculate limit driving forces
IceLoadLimitForce = IceLoadLimitForce.CalcIceLoadLimitForce();

%Calculate restoring coefficients
RestoringCoefficients = RestoringCoefficients.RestoringCoeffC11();
RestoringCoefficients = RestoringCoefficients.RestoringCoeffC22();
RestoringCoefficients = RestoringCoefficients.RestoringCoeffC66();

%Define object of class IceMassLimitMomentum
IceMassLimitMomentum = IceMassLimitMomentum(EnvParameters,IceParameters,RestoringCoefficients);

%Calculate maximum mass of ice feature
IceMassLimitMomentum = IceMassLimitMomentum.CalculateMaxMass();

%% Post-prosessing of data

%Define loads by method for plotting
Method1 = IceLoadRalston.HorizontalForce;
Method1V = IceLoadRalston.VerticalForce;
Method2 = IceLoadCroasdale.HorizontalForce;
Method2V = IceLoadCroasdale.VerticalForce;
Method3 = IceLoadRidgeDolgopolov.HorizontalForce;
Method4 = IceLoadRidgeMellor.HorizontalForce;
Method5 = IceLoadRidgeRalston.HorizontalForceInitial;
Method6 = IceLoadRidgeRalston.HorizontalForceCrack;
Method7 = IceLoadRidgeWang.HorizontalForce;
Method8 = IceLoadManagedIce.HForceScenario1;
Method9 = IceLoadManagedIce.HForceScenario2;
Method10 = IceLoadManagedIce.HForceScenario3;

%Redefine thickness to calculate contribution from first-year ridge 
IceParameters.h = 4;
%Clear old calculations
clear IceLoadRalston IceLoadCroasdale
%Define new object, and perform calculations
IceLoadRalstonConsolidated = IceLoadRalston(Platform,EnvParameters,IceParameters);
IceLoadCroasdaleConsolidated = IceLoadCroasdale(Platform,EnvParameters,IceParameters);
IceLoadRalstonConsolidated = IceLoadRalstonConsolidated.horizontalForce();
IceLoadRalstonConsolidated = IceLoadRalstonConsolidated.verticalForce();
IceLoadCroasdaleConsolidated = IceLoadCroasdaleConsolidated.horizontalForce();
IceLoadCroasdaleConsolidated = IceLoadCroasdaleConsolidated.verticalForce();

%Selects the largest value for the force from the consolidated layer.
if IceLoadRalstonConsolidated.HorizontalForce > IceLoadCroasdaleConsolidated.HorizontalForce
    ConsolidatedLayerH = IceLoadRalstonConsolidated.HorizontalForce;
    ConsolidatedLayerV = IceLoadRalstonConsolidated.VerticalForce;
else
    ConsolidatedLayerH = IceLoadCroasdaleConsolidated.HorizontalForce;
    ConsolidatedLayerV = IceLoadCroasdaleConsolidated.VerticalForce;
end

% Add contribution from the consolidated layer to Dolgopolov and Mellor
Method3 = Method3 + ConsolidatedLayerH;
Method4 = Method4 + ConsolidatedLayerH;

y = [Method1 Method2 Method3 Method4 Method5 Method6 Method7 Method8...
    Method9 Method10];

figure(1)
bar(y)
hold on
grid on
line([0 ; 12],[RestoringCoefficients.C11*25 ; RestoringCoefficients.C11*25],'Color','r')
ylabel('Force, [N]')
xlabel('Ice load method')

%Export plot to Tikz figure for use in Latex.
matlab2tikz( 'iceloads.tikz', 'height', '\figureheight', 'width', '\figurewidth' );
xlabel('Method')
ylabel('Horizontal ice load, [N]')

% Create text-file containing input parameters and results of calculations
IceParameters.h = 2;
CreateResultFile
clear ConsolidatedLayer Method1 Method10 Method1V Method2 Method2V Method3
clear Method4 Method5 Method6 Method7 Method8 Method9 y ans fileID